# bib-dedupe

## dedupe

The [bib-dedupe](https://github.com/CoLRev-Environment/bib-dedupe) package is the default deduplication module for CoLRev.
It is activated by default and is responsible for removing duplicate entries in the data.

## Links

- [bib-dedupe](https://github.com/CoLRev-Environment/bib-dedupe)
